# retico-core-psi
  

This project includes the core functionality of the retico psi module

## How to install
This will also install the retico-core-core modules that are required for all of retico to function


via pip:

  

```bash

$ pip  install  retico-core-psi

```

## Import
```
import configFileReader
import psi_common
import psiAsrReceiver
```

## Retico
Documentation for the main retico project can be found here
[![Documentation Status](https://readthedocs.org/projects/retico-core/badge/?version=latest)](https://retico-core.readthedocs.io/en/latest/?badge=latest)